summaryrefslogtreecommitdiff
path: root/libcxx/test/std/language.support/support.limits/support.limits.general/variant.version.pass.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libcxx/test/std/language.support/support.limits/support.limits.general/variant.version.pass.cpp')
-rw-r--r--libcxx/test/std/language.support/support.limits/support.limits.general/variant.version.pass.cpp55
1 files changed, 39 insertions, 16 deletions
diff --git a/libcxx/test/std/language.support/support.limits/support.limits.general/variant.version.pass.cpp b/libcxx/test/std/language.support/support.limits/support.limits.general/variant.version.pass.cpp
index 5532e04464a..b822eb74fe2 100644
--- a/libcxx/test/std/language.support/support.limits/support.limits.general/variant.version.pass.cpp
+++ b/libcxx/test/std/language.support/support.limits/support.limits.general/variant.version.pass.cpp
@@ -1,4 +1,3 @@
-
//===----------------------------------------------------------------------===//
//
// The LLVM Compiler Infrastructure
@@ -8,26 +7,50 @@
//
//===----------------------------------------------------------------------===//
//
-// <variant> feature macros
+// WARNING: This test was generated by generate_feature_test_macros_tests.py and
+// should not be edited manually.
+
+// <variant>
-/* Constant Value
- __cpp_lib_variant 201606L
+// Test the feature test macros defined by <variant>
+/* Constant Value
+ __cpp_lib_variant 201606L [C++17]
*/
#include <variant>
-#include <cassert>
#include "test_macros.h"
-int main()
-{
-// ensure that the macros that are supposed to be defined in <variant> are defined.
+#if TEST_STD_VER < 14
-/*
-#if !defined(__cpp_lib_fooby)
-# error "__cpp_lib_fooby is not defined"
-#elif __cpp_lib_fooby < 201606L
-# error "__cpp_lib_fooby has an invalid value"
-#endif
-*/
-}
+# ifdef __cpp_lib_variant
+# error "__cpp_lib_variant should not be defined before c++17"
+# endif
+
+#elif TEST_STD_VER == 14
+
+# ifdef __cpp_lib_variant
+# error "__cpp_lib_variant should not be defined before c++17"
+# endif
+
+#elif TEST_STD_VER == 17
+
+# ifndef __cpp_lib_variant
+# error "__cpp_lib_variant should be defined in c++17"
+# endif
+# if __cpp_lib_variant != 201606L
+# error "__cpp_lib_variant should have the value 201606L in c++17"
+# endif
+
+#elif TEST_STD_VER > 17
+
+# ifndef __cpp_lib_variant
+# error "__cpp_lib_variant should be defined in c++2a"
+# endif
+# if __cpp_lib_variant != 201606L
+# error "__cpp_lib_variant should have the value 201606L in c++2a"
+# endif
+
+#endif // TEST_STD_VER > 17
+
+int main() {}